@@ -1,5 +1,7 @@
 /* poppler-page.cc: glib wrapper for poppler
  * Copyright (C) 2005, Red Hat, Inc.
+ * Copyright (C) 2025 Lucas Baudin <lucas.baudin@ensae.fr>
+ * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,8 +35,6 @@
 #include "poppler.h"
 #include "poppler-private.h"
 
-static void _page_unrotate_xy(Page *page, double *x, double *y);
-
 /**
  * SECTION:poppler-page
  * @short_description: Information about a page in a document
@@ -1127,7 +1127,7 @@ GList *poppler_page_get_link_mapping(PopplerPage *page)
 
     poppler_page_get_size(page, &width, &height);
 
-    for (AnnotLink *link : links->getLinks()) {
+    for (const std::shared_ptr<AnnotLink> &link : links->getLinks()) {
         PopplerLinkMapping *mapping;
         PopplerRectangle rect;
         LinkAction *link_action;
@@ -1290,7 +1290,7 @@ GList *poppler_page_get_annot_mapping(PopplerPage *page)
     poppler_page_get_size(page, &width, &height);
     crop_box = page->page->getCropBox();
 
-    for (Annot *annot : annots->getAnnots()) {
+    for (const std::shared_ptr<Annot> &annot : annots->getAnnots()) {
         PopplerAnnotMapping *mapping;
         PopplerRectangle rect;
         gboolean flag_no_rotate;
@@ -1305,6 +1305,9 @@ GList *poppler_page_get_annot_mapping(PopplerPage *page)
         case Annot::typeText:
             mapping->annot = _poppler_annot_text_new(annot);
             break;
+        case Annot::typeInk:
+            mapping->annot = _poppler_annot_ink_new(annot);
+            break;
         case Annot::typeFreeText:
             mapping->annot = _poppler_annot_free_text_new(annot);
             break;
@@ -1438,10 +1441,39 @@ AnnotQuadrilaterals *new_quads_from_offset_cropbox(const PDFRectangle *crop_box,
     return new AnnotQuadrilaterals(std::move(quads_array), len);
 }
 
+/* This function rotates the passed-in @x @y point with the page rotation.
+ * In other words, it moves the point to where it'll be located in a displayed document */
+void _page_rotate_xy(Page *page, double *x, double *y)
+{
+    double page_width, page_height, temp;
+    gint rotation = page->getRotate();
+
+    if (rotation == 90 || rotation == 270) {
+        page_height = page->getCropWidth();
+        page_width = page->getCropHeight();
+    } else {
+        page_width = page->getCropWidth();
+        page_height = page->getCropHeight();
+    }
+
+    if (rotation == 90) {
+        temp = *x;
+        *x = *y;
+        *y = page_height - temp;
+    } else if (rotation == 180) {
+        *x = page_width - *x;
+        *y = page_height - *y;
+    } else if (rotation == 270) {
+        temp = *x;
+        *x = page_width - *y;
+        *y = temp;
+    }
+}
+
 /* This function undoes the rotation of @page in the passed-in @x @y point.
  * In other words, it moves the point to where it'll be located if @page
  * was put to zero rotation (unrotated) */
-static void _page_unrotate_xy(Page *page, double *x, double *y)
+void _page_unrotate_xy(Page *page, double *x, double *y)
 {
     double page_width, page_height, temp;
     gint rotation = page->getRotate();
@@ -1567,12 +1599,12 @@ void poppler_page_add_annot(PopplerPage *page, PopplerAnnot *annot)
     if (page_is_rotated) {
         /* annot is inside a rotated page, as core poppler rect must be saved
          * un-rotated, let's proceed to un-rotate rect before saving */
-        _unrotate_rect_for_annot_and_page(page->page, annot->annot, &x1, &y1, &x2, &y2);
+        _unrotate_rect_for_annot_and_page(page->page, annot->annot.get(), &x1, &y1, &x2, &y2);
     }
 
     annot->annot->setRect(x1 + page_crop_box->x1, y1 + page_crop_box->y1, x2 + page_crop_box->x1, y2 + page_crop_box->y1);
 
-    AnnotTextMarkup *annot_markup = dynamic_cast<AnnotTextMarkup *>(annot->annot);
+    AnnotTextMarkup *annot_markup = dynamic_cast<AnnotTextMarkup *>(annot->annot.get());
     if (annot_markup) {
         crop_box = _poppler_annot_get_cropbox(annot);
         if (crop_box) {
